# Purpose
This directory contains scripts that can be run from the commandline to interact with our application and its associated tools. 

These files should not be imported into django. 

Find out about each of these tools and their options by running them with the --help option. For example:
	>>> python db.py --help